
===================
Answering Selection
===================

Papers
------

* `ABCNN: Attention-Based Convolutional Neural Network for Modeling Sentence Pairs <https://arxiv.org/abs/1512.05193>`_


Codes
-----

* `ABCNN: Attention-Based Convolutional Neural Network for Modeling Sentence Pairs
  <https://github.com/yinwenpeng/Answer_Selection/tree/master/src>`_, based on Theano
* `ABCNN <https://github.com/galsang/ABCNN>`_, based on Tensorflow
* `ABCNN <https://github.com/phdowling/abcnn-keras>`_, based on Keras

